@@ -7,9 +7,9 @@ use overload
     'bool'   => sub {1},
     fallback => 1;
 
-use namespace::sweep;
+use namespace::autoclean;
 
-our $VERSION = '0.304';
+our $VERSION = '0.305';
 
 has 'field'     => ( is => 'rw' );
 has 'op'        => ( is => 'rw' );
@@ -38,9 +38,6 @@ A Clause object represents a leaf in a Query Dialect tree.
 
 =head1 METHODS
 
-This class is a subclass of Rose::ObjectX::CAF. Only new or overridden
-methods are documented here.
-
 =head2 field
 
 =head2 op
