@@ -11,7 +11,7 @@ use Data::Transformer;
 use Scalar::Util qw( blessed );
 use Types::Standard qw( Int Undef );
 use Type::Utils qw( declare as where coerce inline_as from );
-use namespace::sweep;
+use namespace::autoclean;
 
 my $PositiveInt = declare
     as Int,
@@ -33,7 +33,7 @@ has debug         => (
 
 sub _init_debug { $ENV{PERL_DEBUG} || 0 }
 
-our $VERSION = '0.304';
+our $VERSION = '0.305';
 
 =head1 NAME
 
@@ -67,9 +67,6 @@ See Search::Query::Dialect::Native for a working example.
 
 =head1 METHODS
 
-This class is a subclass of Rose::ObjectX::CAF. Only new or overridden
-methods are documented here.
-
 =head2 debug
 
 Get/set flag.
