@@ -5,7 +5,7 @@ use Carp;
 use Data::Dump qw( dump );
 use Search::Query::Field::SQL;
 
-use namespace::sweep;
+use namespace::autoclean;
 
 has 'wildcard'     => ( is => 'rw', default => sub {'%'} );
 has 'quote_fields' => ( is => 'rw', default => sub {''} );
@@ -15,7 +15,7 @@ has 'like'         => ( is => 'rw', default => sub {'ILIKE'}, );
 has 'quote_char'   => ( is => 'rw', default => sub {q/'/}, );
 has 'fuzzy_space'  => ( is => 'rw', default => sub {' '}, );
 
-our $VERSION = '0.304';
+our $VERSION = '0.305';
 
 =head1 NAME
 
