@@ -2,9 +2,9 @@ package Search::Query::Field;
 use Moo;
 use Carp;
 
-use namespace::sweep;
+use namespace::autoclean;
 
-our $VERSION = '0.304';
+our $VERSION = '0.305';
 
 has 'name'      => ( is => 'rw' );
 has 'alias_for' => ( is => 'rw' );
@@ -29,9 +29,6 @@ validation and aliasing in search queries.
 
 =head1 METHODS
 
-This class is a subclass of Rose::ObjectX::CAF. Only new or overridden
-methods are documented here.
-
 =head2 name
 
 Get/set the name of the field.
