@@ -2,14 +2,14 @@ package Search::Query::Field::SQL;
 use Moo;
 extends 'Search::Query::Field';
 
-use namespace::sweep;
+use namespace::autoclean;
 
 has 'type'         => ( is => 'rw' );
 has 'fuzzy_op'     => ( is => 'rw' );
 has 'fuzzy_not_op' => ( is => 'rw' );
 has 'is_int'       => ( is => 'rw' );
 
-our $VERSION = '0.304';
+our $VERSION = '0.305';
 
 =head1 NAME
 
