@@ -2,12 +2,12 @@ package Search::Query::Field::SWISH;
 use Moo;
 extends 'Search::Query::Field';
 
-use namespace::sweep;
+use namespace::autoclean;
 
 has 'type'   => ( is => 'rw' );
 has 'is_int' => ( is => 'rw' );
 
-our $VERSION = '0.304';
+our $VERSION = '0.305';
 
 =head1 NAME
 
