@@ -7,9 +7,9 @@ use Search::Query::Dialect::Native;
 use Search::Query::Clause;
 use Search::Query::Field;
 use Scalar::Util qw( blessed weaken );
-use namespace::sweep;
+use namespace::autoclean;
 
-our $VERSION = '0.304';
+our $VERSION = '0.305';
 
 has 'and_regex' => ( is => 'rw', default => sub {qr/\&|AND|ET|UND|E/i} );
 has 'clause_class' =>
